# pywattbox

The documentation for the API is available at: https://www.snapav.com/wcsstore/ExtendedSitesCatalogAssetStore/attachments/documents/PowerManagement/SupportDocuments/Wattbox%20API%20v2.0.pdf

I suggest not using the admin account to run this code. Log into your WattBox and create a new user account.